@@ -520,6 +520,8 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
                                   time.toString("hh:mm") +
                                   "&REQ0HafasSearchForw=" +
                                   QString::number(mode) +
+                                  "&REQ0JourneyProduct_prod_list=" +
+                                  trainrestr +
                                   "&existOptimizePrice=1&REQ0HafasOptimize1=0%3A1&existProductNahverkehr=yes&REQ0Tariff_TravellerAge.1=35&start=Suchen&REQ0Tariff_Class=2&REQ0Tariff_TravellerReductionClass.1=0";
         filebuffer = new QBuffer();
 
@@ -557,15 +559,15 @@ QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude
     regexp.indexIn(sLatitude);
     sLatitude = regexp.cap(1) + regexp.cap(2);
 
-    QString fullUrl = "http://mobile.bahn.de/bin/mobil/query.exe/eox?rt=1&use_realtime_filter=1&stationNear=1&look_x=" +
+    QString fullUrl = "http://mobile.bahn.de/bin/mobil/query.exe/eol?look_x=" +
                       sLongitude +
                       "&look_y=" +
                       sLatitude +
-                      "&performLocating=2&tpl=stopsnear&look_maxdist=1000&look_stopclass=1023&n=1";
+                      "&performLocating=2&tpl=stopsnear&L=vs_java&look_maxdist=5000&look_maxno=40";
 
-    qDebug()<<"GPS REQUEST URL:"<<fullUrl;
+    //qDebug()<<"GPS REQUEST URL:"<<fullUrl;
 
-    qDebug()<<"GPS RAW VALUES: LAT"<<latitude<<" LONG:"<<longitude;
+    //qDebug()<<"GPS RAW VALUES: LAT"<<latitude<<" LONG:"<<longitude;
 
     QUrl url(fullUrl);
 
@@ -591,7 +593,7 @@ QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
     //Query for Gps infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/div/a[@class='uLine']/string()");
+    query.setQuery("doc($path)/ResC/MLcRes/MLc[@t='ST']/@n/string()");
 
     QStringList result;
     if (!query.evaluateTo(&result))
@@ -609,10 +611,12 @@ QStringList parserMobileBahnDe::getStationsByGPS(qreal latitude, qreal longitude
 
 QStringList parserMobileBahnDe::getStationsByName(QString stationName)
 {
-    QByteArray postData = "REQ0JourneyStopsS0A=1&REQ0JourneyStopsS0G=";
+    stationName.replace("\"", "");
+    QByteArray postData = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?><ReqC ver=\"1.1\" prod=\"String\" lang=\"EN\"><MLcReq><MLc n=\"";
     postData.append(stationName);
+    postData.append("\" t=\"ST\" /></MLcReq></ReqC>");
 
-    QUrl url("http://mobile.bahn.de/bin/mobil/query.exe/eox?rt=1&use_realtime_filter=1&searchMode=NORMAL");
+    QUrl url("http://mobile.bahn.de/bin/mobil/query.exe/en");
 
     http->setHost(url.host(), QHttp::ConnectionModeHttp, url.port() == -1 ? 0 : url.port());
 
@@ -639,23 +643,13 @@ QStringList parserMobileBahnDe::getStationsByName(QString stationName)
 
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
-    //Query for more than one result
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/form/div/select[@name='REQ0JourneyStopsS0K']/option/string()");
+    //Query for station infos
+    query.setQuery("doc($path)/ResC/MLcRes/MLc[@t='ST']/@n/string()");
 
     QStringList result;
     if (!query.evaluateTo(&result))
     {
-        qDebug() << "parserMobileBahnDe::getStationsByName - Query 1 Failed";
-    }
-
-    if (result.count() == 0)
-    {
-        //Query for only one result
-        query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/form/div/span[@class='fixedLoc']/string()");
-        if (!query.evaluateTo(&result))
-        {
-            qDebug() << "parserMobileBahnDe::getStationsByName - Query 2 Failed";
-        }
+        qDebug() << "parserMobileBahnDe::getStationsByName - Query Failed";
     }
 
     delete filebuffer;
